# yupi

Standing for *Yet Underused Path Instruments*, yupi is a set of tools designed for collecting and processing trajectory data. A detailed description of the API can be found in the [official documentation](https://yupi.readthedocs.io/en/latest/). Code examples (with additional multimedia resources) can be found in [this repository](https://github.com/yupidevs/yupi_examples).

## Instalation

Current recommended installation method is via the pypi package:

```cmd
pip install yupi
```
